@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'sahara::db::postgresql' do
 
-  shared_examples_for 'sahara::db::postgresql' do
+  shared_examples 'sahara::db::postgresql' do
     let :req_params do
       { :password => 'saharapass' }
     end
@@ -39,7 +39,10 @@ describe 'sahara::db::postgresql' do
         }))
       end
 
-      it_configures 'sahara::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_configures 'sahara::db::postgresql'
+      end
     end
   end
 
